"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const utils_1 = require("./utils");
const hash_sum_1 = __importDefault(require("hash-sum"));
const slash_1 = __importDefault(require("slash"));
const mime_types_1 = __importDefault(require("mime-types"));
const debug = require('debug')('vite:build:asset');
// TODO make this configurable
const inlineThreshold = 10000;
exports.getAssetPublicPath = async (id, assetsDir) => {
    const ext = path_1.default.extname(id);
    const baseName = path_1.default.basename(id, ext);
    const resolvedFileName = `${baseName}.${hash_sum_1.default(id)}${ext}`;
    let url = slash_1.default(path_1.default.join('/', assetsDir, resolvedFileName));
    const content = await fs_1.promises.readFile(id);
    if (!id.endsWith(`.svg`)) {
        if (content.length < inlineThreshold) {
            url = `data:${mime_types_1.default.lookup(id)};base64,${content.toString('base64')}`;
        }
    }
    return {
        content,
        fileName: resolvedFileName,
        url
    };
};
exports.registerAssets = (assets, bundle) => {
    for (const [fileName, source] of assets) {
        bundle[fileName] = {
            isAsset: true,
            type: 'asset',
            fileName,
            source
        };
    }
};
exports.createBuildAssetPlugin = (assetsDir) => {
    const assets = new Map();
    return {
        name: 'vite:asset',
        async load(id) {
            if (utils_1.isStaticAsset(id)) {
                const { fileName, content, url } = await exports.getAssetPublicPath(id, assetsDir);
                assets.set(fileName, content);
                debug(`${id} -> ${url}`);
                return `export default ${JSON.stringify(url)}`;
            }
        },
        generateBundle(_options, bundle) {
            exports.registerAssets(assets, bundle);
        }
    };
};
