"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const buildPluginAsset_1 = require("./buildPluginAsset");
const debug = require('debug')('vite:css');
const urlRE = /(url\(\s*['"]?)([^"')]+)(["']?\s*\))/g;
exports.createBuildCssPlugin = (assetsDir, cssFileName, minify) => {
    const styles = new Map();
    const assets = new Map();
    return {
        name: 'vite:css',
        async transform(code, id) {
            if (id.endsWith('.css')) {
                // process url() - register referenced files as assets
                // and rewrite the url to the resolved public path
                if (urlRE.test(code)) {
                    const fileDir = path_1.default.dirname(id);
                    urlRE.lastIndex = 0;
                    let match;
                    let remaining = code;
                    let rewritten = '';
                    while ((match = urlRE.exec(remaining))) {
                        rewritten += remaining.slice(0, match.index);
                        const [matched, before, rawUrl, after] = match;
                        const file = path_1.default.resolve(fileDir, rawUrl);
                        const { fileName, content, url } = await buildPluginAsset_1.getAssetPublicPath(file, assetsDir);
                        assets.set(fileName, content);
                        debug(`url(${rawUrl}) -> url(${url})`);
                        rewritten += `${before}${url}${after}`;
                        remaining = remaining.slice(match.index + matched.length);
                    }
                    code = rewritten + remaining;
                }
                styles.set(id, code);
                return '/* css extracted by vite */';
            }
        },
        async generateBundle(_options, bundle) {
            let css = '';
            // finalize extracted css
            styles.forEach((s) => {
                css += s;
            });
            // minify with cssnano
            if (minify) {
                css = (await require('postcss')([require('cssnano')]).process(css, {
                    from: undefined
                })).css;
            }
            bundle[cssFileName] = {
                isAsset: true,
                type: 'asset',
                fileName: cssFileName,
                source: css
            };
            buildPluginAsset_1.registerAssets(assets, bundle);
        }
    };
};
