"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = __importDefault(require("http"));
const koa_1 = __importDefault(require("koa"));
const chokidar_1 = __importDefault(require("chokidar"));
const resolver_1 = require("./resolver");
const serverPluginModuleRewrite_1 = require("./serverPluginModuleRewrite");
const serverPluginModuleResolve_1 = require("./serverPluginModuleResolve");
const serverPluginVue_1 = require("./serverPluginVue");
const serverPluginHmr_1 = require("./serverPluginHmr");
const serverPluginServeStatic_1 = require("./serverPluginServeStatic");
const serverPluginJson_1 = require("./serverPluginJson");
const serverPluginCss_1 = require("./serverPluginCss");
const internalPlugins = [
    serverPluginModuleRewrite_1.moduleRewritePlugin,
    serverPluginModuleResolve_1.moduleResolvePlugin,
    serverPluginVue_1.vuePlugin,
    serverPluginJson_1.jsonPlugin,
    serverPluginCss_1.cssPlugin,
    serverPluginHmr_1.hmrPlugin,
    serverPluginServeStatic_1.serveStaticPlugin
];
function createServer(config = {}) {
    const { root = process.cwd(), plugins = [], resolvers = [] } = config;
    const app = new koa_1.default();
    const server = http_1.default.createServer(app.callback());
    const watcher = chokidar_1.default.watch(root, {
        ignored: [/node_modules/]
    });
    const resolver = resolver_1.createResolver(root, resolvers);
    [...plugins, ...internalPlugins].forEach((m) => m({
        root,
        app,
        server,
        watcher,
        resolver
    }));
    return server;
}
exports.createServer = createServer;
