"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const serverPluginHmr_1 = require("./serverPluginHmr");
const hash_sum_1 = __importDefault(require("hash-sum"));
exports.cssPlugin = ({ app, watcher, resolver }) => {
    app.use(async (ctx, next) => {
        await next();
        // handle .css imports
        // we rewrite it to JS that injects a <style> tag pointing to the same url
        // but with a `?raw` query which returns the actual css
        if (ctx.path.endsWith('.css') &&
            utils_1.isImportRequest(ctx) &&
            // note ctx.body could be null if upstream set status to 304
            ctx.body &&
            // skip raw requests
            !ctx.query.raw) {
            ctx.type = 'js';
            const id = JSON.stringify(hash_sum_1.default(ctx.path));
            const rawPath = JSON.stringify(ctx.path + '?raw');
            ctx.body = `
import { updateStyle } from "${serverPluginHmr_1.hmrClientId}"\n
updateStyle(${id}, ${rawPath})
`.trim();
        }
    });
    // handle hmr
    watcher.on('change', (file) => {
        if (file.endsWith('.css')) {
            const publicPath = resolver.fileToRequest(file);
            const id = hash_sum_1.default(publicPath);
            watcher.send({
                type: 'style-update',
                id,
                path: publicPath,
                timestamp: Date.now()
            });
        }
    });
};
